# book2anki

Reads a text file and turns it into Anki cards. Automatically retrieves glosses from wwwjdic and reformats them in a cleaner way, plus separates definitions that are probably already known away from the main definitions field (uses Japana for word frequency analysis).
